==> haskell-hslua-module-zip-1.1.3-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.3
visibility:           public
id:                   hslua-module-zip-1.1.3-HdI7yzPSadO8D7H9pN7xWK
key:                  hslua-module-zip-1.1.3-HdI7yzPSadO8D7H9pN7xWK
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  d69ef000eb4e8fba2690fadecfb4e9c3
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.3-HdI7yzPSadO8D7H9pN7xWK
depends:
    base-4.17.2.1 bytestring-0.11.5.3 filepath-1.4.2.2
    hslua-core-2.3.2-IEUyD5lML2z7g5VUEGRC82
    hslua-list-1.1.3-8trMHIzFDlvApMZQ6Tr8re
    hslua-marshalling-2.3.1-IGOD8k4ePjg50VapA6mI1m
    hslua-packaging-2.3.1-FM0YZ1XsQDf5dhCzyKuPvI
    hslua-typing-0.1.1-9E8ITZjowFG893WXrYIEWO text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-5s6UP7erHPJ4ZzDGvXywNZ

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-zip-1.1.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.3
visibility:           public
id:                   hslua-module-zip-1.1.3-FzMa7INCfa1GeB0qknKXWS
key:                  hslua-module-zip-1.1.3-FzMa7INCfa1GeB0qknKXWS
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  b8223c6bc4c538f7cf84c80688bfd220
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.3-FzMa7INCfa1GeB0qknKXWS
depends:
    base-4.17.2.1 bytestring-0.11.5.3 filepath-1.4.2.2
    hslua-core-2.3.2-7DQMNXPNqjJFnBPjIyvcoH
    hslua-list-1.1.3-JnSrYSahUVm1tAznV8P9Uv
    hslua-marshalling-2.3.1-IobdForZPq5BlkJKSOSy5m
    hslua-packaging-2.3.1-4D3lEjkESyxG2C7UkdWZGL
    hslua-typing-0.1.1-1KT3KqVAVIx9cWx8GHSXCV text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-KyWgjSk3ONNGST144pTgVY

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
